@@ -1,5 +1,5 @@
 import gnomevfs
-import os
+import logging
 from deskbar.handlers.actions.OpenWithApplicationAction import OpenWithApplicationAction
 from deskbar.handlers.actions.CopyToClipboardAction import CopyToClipboardAction
 from deskbar.handlers.actions.GoToLocationAction import GoToLocationAction
@@ -7,6 +7,8 @@ from deskbar.handlers.actions.SendFileViaEmailAction import SendFileViaEmailActi
 from os.path import basename, isdir
 from gettext import gettext as _
 
+LOGGER = logging.getLogger(__name__)
+
 def get_actions_for_uri(uri, display_name=None):
     """
     Return a list of applications suitable for
@@ -27,16 +29,17 @@ def get_actions_for_uri(uri, display_name=None):
         uri = "file://"+path
     if display_name == None:
         display_name = basename(path)
-        
-    # Check if path exists and is readable
-    if not os.access(path, os.F_OK | os.R_OK):
-        return []
     
     # If we have a directory only return one action
     if isdir(path):
         return [CopyToClipboardAction( _("Location"), path)]
-    
-    mime = gnomevfs.get_mime_type(uri)
+        
+    try:
+        fileinfo = gnomevfs.get_file_info(uri, gnomevfs.FILE_INFO_GET_MIME_TYPE | gnomevfs.FILE_INFO_FOLLOW_LINKS)
+    except Exception, msg:
+        LOGGER.error("Could not retrieve MIME type of %s: %s" % (uri, msg))
+        return []
+    mime = fileinfo.mime_type
     actions = []
     
     mime_default_cmd = gnomevfs.mime_get_default_application(mime)
@@ -50,8 +53,16 @@ def get_actions_for_uri(uri, display_name=None):
         # 3: can open multiple files (bool)
         # 4: expects_uri (int)
         # 5: supported uri schemes (list)
-        if mime_default_cmd == None or app[2] != mime_default_cmd:
-            actions.append( OpenWithApplicationAction(display_name, app[2], [path],
+        if (mime_default_cmd == None or app[2] != mime_default_cmd) and app[2] != None:
+            cmd = app[2]
+            args = [path]
+            
+            cmd_args = cmd.split(" ")
+            if len(cmd_args) > 0:
+                cmd = cmd_args[0]
+                args = cmd_args[1:] + args
+            
+            actions.append( OpenWithApplicationAction(display_name, cmd, args,
                     display_program_name=app[1]) )
     
     actions.append( GoToLocationAction(display_name, uri) )
