@@ -2,6 +2,7 @@ import gtk
 import gtk.gdk
 import gnomevfs
 import logging
+import deskbar
 import deskbar.interfaces.Controller
 import deskbar.core.Utils
 from deskbar.ui.About import show_about
@@ -37,9 +38,12 @@ class CuemiacWindowController(deskbar.interfaces.Controller):
         if self._model.get_clear_entry():
             self._view.clear_all()
         window = self._view.get_toplevel()
-        x, y = window.get_position()      
-        self._model.set_window_x(x)      
-        self._model.set_window_y(y)
+        x, y = window.get_position()
+        
+        if self._model.get_ui_name() == deskbar.WINDOW_UI_NAME:
+            self._model.set_window_x(x)
+            self._model.set_window_y(y)
+        
         window.hide()
         return True
 
@@ -167,4 +171,4 @@ class CuemiacWindowController(deskbar.interfaces.Controller):
         
     def on_category_added (self, widget, cat, path):
         if cat.get_id() not in self._model.get_collapsed_cat():
-            self._view.cview.expand_row (path, False)
\ No newline at end of file
+            self._view.cview.expand_row (path, False)
